==========================
Frequently Asked Questions
==========================

Contents
********

.. contents::
    :local:
    :class: toggle:
 

Why doesn't the Espresso API include <feature>?
-----------------------------------------------
Our design philosophy centres around having a universal interface that enables users to access a range of test problems without detailed domain knowledge. We think this means we should keep the API as small and tightly-defined as possible, to ensure that it can accommodate the widest range of problems and users.

Nevertheless, we welcome suggestions! You can propose a new API feature by `opening an issue <https://github.com/inlab-geo/espresso/issues>`_.

I've got an idea for a new test problem!
----------------------------------------
Great! We welcome suggestions and contributions. You can tell us about your idea by `opening an issue <https://github.com/inlab-geo/espresso/issues>`_. You can also have a go at adding the test problem yourself --- take a look at the :doc:`../contributor_guide/index`